@@ -1,6 +1,7 @@
+import json
 import os
 import re
-from typing import Dict, Callable, Tuple
+from typing import Dict, Callable, Tuple, Union
 from urllib.parse import urljoin
 
 import optuna
@@ -56,7 +57,13 @@ def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Di
 
 
 @util.login_required
-def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Dict = None) -> (bool, int):
+def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Union[str, Dict] = None) -> (bool, int):
+
+    if isinstance(hpo_config, str):
+        # str 인 경우 파일을 읽어서 hpo_config json(dict)를 생성
+        with open(hpo_config, "rb") as f:
+            hpo_config = json.loads(f.read())
+
     # hpo_config['parameters']를 REST API스펙에 맞게 key-value 형식으로 변환
     if hpo_config and 'parameters' in hpo_config:
         parameters_dict = hpo_config['parameters']
@@ -133,8 +140,8 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
 
 
 @util.login_required
-def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Dict = None,
-            func: Callable = None, count: int = 10, artifact: Dict = None, job_count: int = 0) -> bool:
+def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Dict  = None,
+            func: Callable = None, count: int = 10, artifact: Union[str, Dict] = None, job_count: int = 0) -> bool:
     # assert_that(func).is_not_none()
 
     result1, hpoConfig, team_name_from_hpo = get_hpo(exp_name=exp_name, team_name=team_name)
@@ -142,6 +149,12 @@ def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_c
         raise Exception("HPO not found")
     result2, study = load_hpo(exp_name=exp_name, team_name=team_name_from_hpo)
 
+    if isinstance(artifact, str):
+        # artifact 가 str인 경우 path로 보고 파일을 읽어서 json(dict)로 만듬
+        with open(artifact,  "rb") as f:
+            artifact = json.loads(f.read())
+
+
     if artifact:
         if not get_run():
             deepdriver.init(exp_name=artifact["code"]["exp_name"])
