@@ -109,7 +109,14 @@ def post(url: str, data: Dict) -> Dict:
     logger.debug(f"REST[POST] to [{url}] : data=[{json.dumps(data)}], headers=[{get_headers()}")
     rsp = requests.post(url, headers=get_headers(), data=json.dumps(data))
     if rsp.status_code not in [200, 201]:
-        logger.error(f"post({url}) failed({rsp.status_code})")
+        logger.debug(f"post({url}) failed({rsp.status_code})")
+        try:
+            if json.loads(rsp.text)['result'] == 'fail':
+                if json.loads(rsp.text)['message'] == "INVALID KEY":
+                    logger.error("Invalid Login Token.")
+                    raise Exception("Invalid Login Token.")
+        except Exception as e :
+            pass
         raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
     return dict(json.loads(rsp.text))
 
